@@ -5,13 +5,13 @@ import argparse
 import os
 import sys
 import select
-# import random
 import zipfile
 import re
 from getpass import getpass
+import html
 
 from tqdm import tqdm
-from pyrogram.session import Session 
+from pyrogram.session import Session
 from pyrogram import Client, filters, types, session
 
 BASE_FOLDER = Path(__file__).parent.absolute()
@@ -25,12 +25,12 @@ class Bot:
         self.__config.read(folder_name / "config.ini")
 
         self.app = Client(session_name=str(self.folder_name / "my_account"), api_id=self.__config['credentials']['pyrogram_api_id'],
-                    api_hash=self.__config['credentials']['pyrogram_api_hash'], parse_mode="html", no_updates=True, hide_password=True) 
+                    api_hash=self.__config['credentials']['pyrogram_api_hash'], parse_mode="html", no_updates=True, hide_password=True)
 
     def __enter__(self):
         self.app.start()
         return self.app
-    
+
     def __exit__(self, type, value, traceback):
         self.app.stop()
 
@@ -65,9 +65,9 @@ def send_data(data: str, user:str = "me", data_type:str = "text", caption: str =
             else:
                 app.send_message(user, data, parse_mode = parse_mode)
         elif data_type == "file":
-            with tqdm(total=100) as pbar:  
+            with tqdm(total=100) as pbar:
                 def progress(current, total):
-                    pbar.update(round(current * 100 / total, 4) - pbar.n) 
+                    pbar.update(round(current * 100 / total, 4) - pbar.n)
                 if caption is not None:
                     app.send_document(user, data, caption=caption[:1024], progress=progress)
                 else:
@@ -78,18 +78,18 @@ def main():
     """
     Parse args, validate data
     """
-    parser = argparse.ArgumentParser(description='Pipe stdout and files to telegram(via userbot)')
+    parser = argparse.ArgumentParser(description='Pipe stdout and files to telegram(via userbot).')
     parser.add_argument('message',  nargs='*', action="store", type=str, help='specify text of message to send, html parsing enabled, overwrites pipes.')
     parser.add_argument('-u', '--user', action="store", type=str, help='specify user to send, default is you.')
     parser.add_argument('-f', '--file', action="store", type=str, help='send file, text will be sended as caption. If folder is sended, will zip and send')
-    parser.add_argument('-c', '--code', action='store_true', help='send text with <code> text to make it monospace')
+    parser.add_argument('-c', '--code', action='store_true', help='send text with <code> text to make it monospace, apply tags escaping and send as html')
     parser.add_argument('-F', '--force-file', action='store_true', help='send text in file even if it is shorter than 4096 symbols')
-    parser.add_argument('--no-html', action='store_true', help='do not parse as html')
-    parser.add_argument('--ansi-colors', action='store_true', help="don't remove ANSI escape codes from piped strings")
     parser.add_argument('--new-user', action='store_true', help='reloging to telegram')
     parser.add_argument('--new-app', action='store_true', help='enter new api_id/api_hash combination')
+    parser.add_argument('--html', action='store_true', help='parse as html and apply <b>, <i> etc. tags')
+    parser.add_argument('--ansi-colors', action='store_true', help="don't remove ANSI escape codes from piped strings")
     args = parser.parse_args()
-    
+
     # Pipe handling
     pipe = None
     if select.select([sys.stdin, ], [], [], 0.0)[0]:
@@ -97,11 +97,11 @@ def main():
         if not args.ansi_colors:
             ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
             pipe = ansi_escape.sub('', pipe)
-    
-    if args.no_html:
-        parse_mode = None
-    else:
+
+    if args.html:
         parse_mode = "html"
+    else:
+        parse_mode = None
 
     # Text handling
     message_text = None
@@ -112,16 +112,20 @@ def main():
     elif args.file is not None:
         pass
     else:
-        print("No message to send, sending test message to Saved Messages. For help, use -h, --help.")
+        print("No message to send, sending lirum test message to Saved Messages. For help, use -h, --help.")
         # message_text = hex(random.randrange(0x10000000000, 0x99999999999))
         message_text = f"Hello World!\n\n\n<i>With Love from teleout</i>"
+        parse_mode = "html"
 
     as_file = False
     if message_text is None or len(message_text) > 4000 or args.force_file:
         as_file = True
 
     if args.code and not as_file:
+        message_text = html.escape(message_text)
         message_text = "<code>{}</code>".format(message_text)
+        parse_mode = 'html'
+
 
     # File handling
     delete_file = False
@@ -133,7 +137,7 @@ def main():
         elif file.is_dir():
             delete_file = True
             file = zipdir(file)
-    
+
     # New user handling
     if args.new_user:
         session_file = BASE_FOLDER / Path("secret_data/my_account.session")
@@ -159,4 +163,7 @@ def main():
         file.unlink()
 
 if __name__ == "__main__":
-    main()
+    try:
+        main()
+    except KeyboardInterrupt:
+        sys.exit("\nCancelling...")
